.attachment-link-list{list-style-type:none;padding:0;margin-bottom:0}.attachment-link-list .attachment-link{margin-top:20px}.attachment-link-list .attachment-container{border-radius:4px;background-color:#fff;border:1px solid #e5e7eb;-ms-align-items:center;-webkit-align-items:center;align-items:center;-ms-flex-align:center}.attachment-link-list .attachment-container .officeDocumentIcon.document-icon-word{color:#2b549e}.attachment-link-list .attachment-container .officeDocumentIcon.document-icon-excel{color:#1e5635}.attachment-link-list .attachment-container .officeDocumentIcon.document-icon-powerpoint{color:#d24527}.attachment-link-list .attachment-container .officeDocumentIcon.document-icon-access{color:#a53636}.attachment-link-list .attachment-container .officeDocumentIcon.document-icon-pdf{color:#ef4444}.attachment-link-list .attachment-container .officeDocumentIcon.document-icon-3d_model{color:#eab308}.attachment-link-list .column{padding:16px 0;min-width:0}.attachment-link-list img{margin-left:10px}.attachment-link-list a:hover{text-decoration:none}.attachment-link-list a p{color:#1f2937}.attachment-link-list p{margin:0 10px}.attachment-link-list p.attachment-subtitle{font-size:12px;font-weight:400;color:#6b7484}.attachment-link-list p.attachment-subtitle.price{color:#e83d16}.attachment-link-list p.attachment-subtitle.supplier{color:#b98d06}.attachment-link-list p.attachment-info{font-size:11px}.attachment-link-list .button{margin-right:15px}.attachment-link-list .button:hover{border-color:#d1d5db}.attachment-link-list .attachment-icon{display:-ms-flexbox;display:-webkit-flex;display:flex;-ms-align-items:center;-webkit-align-items:center;align-items:center;-ms-flex-align:center;-ms-justify-content:center;-webkit-justify-content:center;justify-content:center;-ms-flex-pack:center;width:64px;-ms-align-self:stretch;-webkit-align-self:stretch;align-self:stretch;-ms-flex-item-align:stretch;text-align:center;margin-right:10px;background-color:#f2f2f2}.remove-doc-container{display:-ms-flexbox;display:-webkit-flex;display:flex;-ms-align-items:center;-webkit-align-items:center;align-items:center;-ms-flex-align:center;-ms-flex:0 0 40px;-webkit-flex:0 0 40px;flex:0 0 40px;height:56px;cursor:pointer}.remove-doc-container a.removeLink{display:-ms-flexbox;display:-webkit-flex;display:flex;-ms-justify-content:center;-webkit-justify-content:center;justify-content:center;-ms-flex-pack:center;-ms-flex-direction:column;-webkit-flex-direction:column;flex-direction:column;color:#d1d5db;margin:auto;height:100%}.remove-doc-container:active,.remove-doc-container:hover{background-color:#eaeaea}.remove-doc-container:active a.removeLink,.remove-doc-container:hover a.removeLink{border:none}.remove-doc-container:active a.removeLink i,.remove-doc-container:hover a.removeLink i{color:#ef4444}.attachment-link-list.three-columns,.attachment-link-list.two-columns{display:-ms-flexbox;display:-webkit-flex;display:flex;-ms-flex-flow:row wrap;-webkit-flex-flow:row wrap;flex-flow:row wrap;-ms-align-items:stretch;-webkit-align-items:stretch;align-items:stretch;-ms-flex-align:stretch;margin-left:-20px}.attachment-link-list.three-columns .attachment-link,.attachment-link-list.two-columns .attachment-link{-ms-flex:1 0 50%;-webkit-flex:1 0 50%;flex:1 0 50%;display:-ms-flexbox;display:-webkit-flex;display:flex;-ms-flex-direction:column;-webkit-flex-direction:column;flex-direction:column;min-width:230px}.attachment-link-list.three-columns .attachment-container,.attachment-link-list.two-columns .attachment-container{-ms-flex:1 0 auto;-webkit-flex:1 0 auto;flex:1 0 auto;margin-left:20px;margin-bottom:0}@media only screen and (max-width:599px){.attachment-link-list.three-columns,.attachment-link-list.two-columns{margin-left:0}.attachment-link-list.three-columns .attachment-container,.attachment-link-list.two-columns .attachment-container{margin-left:0}.attachment-link-list.three-columns .attachment-link,.attachment-link-list.two-columns .attachment-link{-ms-flex:0 0 100%;-webkit-flex:0 0 100%;flex:0 0 100%}}@media only screen and (min-width:1001px){.attachment-link-list.three-columns .attachment-link{-ms-flex:1 0 33.33%;-webkit-flex:1 0 33.33%;flex:1 0 33.33%}}