.cart-banner{display:-ms-flexbox;display:-webkit-flex;display:flex;-ms-flex-direction:row;-webkit-flex-direction:row;flex-direction:row;-ms-justify-content:flex-start;-webkit-justify-content:flex-start;justify-content:flex-start;-ms-flex-pack:start;-ms-align-items:center;-webkit-align-items:center;align-items:center;-ms-flex-align:center;width:100%;background-size:270px;background-repeat:no-repeat;image-rendering:-webkit-optimize-contrast}.cart-banner .cart-banner-text{font-size:16px}.cart-banner .cart-banner-text strong{font-weight:700!important}.cart-banner .browse-store-button{margin-left:50px;max-width:200px;color:#212426;font-size:14px;border:1px solid #e9eaeb;padding:10px 20px;font-weight:400}.cart-banner .browse-store-button:hover{background:linear-gradient(to right,#f5f5f6,rgba(246,246,246,.4))}.cart-banner.location-in-cart{-ms-justify-content:flex-end;-webkit-justify-content:flex-end;justify-content:flex-end;-ms-flex-pack:end;height:75px;border-top:1px solid #e9eaeb;background-position:left -100px top -40px}@media only screen and (min-width:1001px),only screen and (min-width:600px) and (max-width:1000px){.cart-banner.location-in-cart p{top:25px}}.cart-banner.location-in-cart p.cart-banner-text{padding-left:150px}@media only screen and (max-width:599px){.cart-banner.location-in-cart p.cart-banner-text{padding-left:130px}}@media only screen and (max-width:599px){.cart-banner.location-in-cart{height:120px}}.cart-banner.location-product,.cart-banner.location-store{margin-top:20px;height:100px;background-size:400px;background-position:right -135px top -70px;border:1px solid #e9eaeb;border-radius:5px}.cart-banner.location-product .browse-store-button,.cart-banner.location-store .browse-store-button{display:none}.cart-banner.location-product p,.cart-banner.location-store p{margin-left:30px;margin-right:200px;min-width:175px}@media only screen and (max-width:599px){.cart-banner.location-product,.cart-banner.location-store{height:120px;margin-bottom:10px;background-size:300px;background-position:right -100px top -35px}.cart-banner.location-product p,.cart-banner.location-store p{margin-left:15px}}@media only screen and (min-width:600px) and (max-width:1000px){.cart-banner.location-product p,.cart-banner.location-store p{max-width:300px}}@media only screen and (min-width:1001px){.cart-banner.location-store{margin-top:35px;margin-bottom:35px;background-position:right -35px top -70px}.cart-banner.location-store p{font-size:21px;max-width:500px}}@media only screen and (min-width:600px) and (max-width:1000px){.cart-banner.location-store{margin-left:20px;width:calc(100% - 40px)}}